@@ -314,6 +314,7 @@ class Cursor(DBAPICursor):
         _logger.info("fetching all from overriden method")
         self._data = list()
         while len(self._data) < self.rowcount():
+            _logger.info(len(self._data))
             _logger.info("fetching next batch from fetch all")
             rows = self.fetch_batch()
             self._data = self._data + rows
@@ -338,10 +339,13 @@ class Cursor(DBAPICursor):
     def fetchmany(self, size=10000):
         _logger.info("fetching all from overriden method")
         size = min(size, self.rowcount())
+        row_count = 0
         self._data = list()
-        while len(self._data) < size:
+        while row_count < size:
             _logger.info("fetching next batch from fetch many")
+            _logger.info(len(self._data))
             rows = self.fetch_batch()
+            row_count = row_count + len(rows)
             self._data = self._data + rows
         return self._data if len(self._data) == size else self._data[0:size]
 
